@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"1.0.1"
\ No newline at end of file
+version="1.0.4"
